@@ -9,18 +9,11 @@
 #pragma warning (disable: 4996)
 #endif
 
-// enable ASSERT() on linux 
-#ifndef _WIN32
-#ifndef _DEBUG
-#define _DEBUG
-#endif
-
-#else
-#include <assert.h>
+#ifdef _WIN32
 #define CHARLS_DLL
 #endif
 
-#include <stdio.h>
+#include <cstdio>
 
 typedef unsigned char BYTE;
 typedef unsigned short USHORT;
