@@ -6,6 +6,8 @@
 #define TEST_UTIL
 
 #include "../src/util.h"
+#include <vector>
+#include <exception>
 
 typedef const char* SZC;
 
@@ -17,4 +19,21 @@ void TestRoundTrip(const char* strName, std::vector<BYTE>& rgbyteRaw, Size size,
 void WriteFile(SZC strName, std::vector<BYTE>& vec);
 void DecompressFile(SZC strNameEncoded, SZC strNameRaw, int ioffs, bool bcheckEncode = true);
 
+class UnitTestException : public std::exception {
+public:
+    explicit UnitTestException() : exception()
+    {
+    }
+};
+
+class Assert
+{
+public:
+    static void IsTrue(bool condition)
+    {
+        if (!condition)
+            throw UnitTestException();
+    }
+};
+
 #endif
